def main():
    import argparse

    parser = argparse.ArgumentParser()
    parser.add_argument('-t', '--test', action='store_true',
                        help="testing code by starting flask, "
                             "used for another file to test - e2e.py")
    arg = parser.parse_args()
    if arg.test:
        from .MainScores import MainScores

        MainScores().start_option()

    else:
        from .Live import welcome, load_game

        user_name = input("Hi, What is your name? ")
        print(f"{welcome(user_name)}\n")
        load_game()



import random
from time import sleep
from .Utils import Utils
from .Game import Game


class MemoryGame(Game):
    """
    This class is a memory game, it generates a random number/s,
    shows it to the user for 0.7 sec and the user needs to enter the right number/s.
    """
    def __init__(self):
        """
        This func runs automatically every time a user calls
        the class and it initializes the necessary variables.
        """
        Game.__init__(self)
        self.list_rand_numbers = []
        self.list_user_numbers = []
        self.rand_num = random.randint(1, 101)
        self.user_input = 0

    def generate_sequence(self):
        # generates a list (length depends on the game difficulty) of numbers.
        for i in range(self.game_difficulty):
            self.list_rand_numbers.append(self.rand_num)
            self.rand_num = random.randint(1, 101)
        self.list_rand_numbers.sort()

    def get_list_from_user(self):
        # The user needs to enter the numbers he just saw.
        print(f"You need to insert the {self.game_difficulty} numbers that just disappeared ")
        for i in range(self.game_difficulty):
            user_input = input(f"Please insert one of the numbers that you saw ")
            user_input = Utils()._needs_number(user_input)
            self.list_user_numbers.append(user_input)
        self.list_user_numbers.sort()

    def is_list_equal(self):
        # Check if the user is correct and it returns accordingly.
        temp_list = []
        for num in self.list_rand_numbers:
            temp_list.append(num)
        for num in self.list_user_numbers:
            if num in temp_list:
                temp_list.remove(num)
        return len(temp_list) == 0

    def play(self):
        """
        When a user wants to play this game, he needs to call this func
        and it runs the relevant methods in the correct order.
        :return: True/False whether the user wins/loses.
        """
        self.generate_sequence()
        print(self.list_rand_numbers)
        sleep(0.7)
        Utils().screen_cleaner()
        self.get_list_from_user()
        print(f"The computer's numbers are - {self.list_rand_numbers}")
        print(f"Your numbers that you entered are - {self.list_user_numbers}")
        self.winning_status = self.is_list_equal()



from .CurrencyRouletteGame import *
from .Game import *
from .GuessGame import *
from .Live import *
from .MainGame import *
from .MemoryGame import *
from .Utils import *
from .Score import *
from .MainScores import *


from .Utils import *
import os


class Score(Utils):
    """
    A class that is in charge of managing the scores file.
    """
    def __init__(self, difficulty):
        """
        This runs every time a user calls the class
        and it initializes necessary variables.
        """
        Utils.__init__(self)
        self.difficulty = difficulty
        self.points_of_winning = (self.difficulty * 3) + 5

    def add_score(self):
        """
        The function will try to read the current score in the scores file,
        if it fails it will create a new one and will use it to save the current score.
        """
        if not (os.path.exists(os.path.join(self.path_files, self.scores_file_name))):
            with open(os.path.join(self.path_files, self.scores_file_name), "w+") as scores_file:
                scores_file.write("0")
        with open(os.path.join(self.path_files, self.scores_file_name), "a+") as scores_file:
            scores_file.seek(0)
            sum_score = scores_file.read()
            sum_score = int(sum_score)
            sum_score = sum_score + self.points_of_winning
            scores_file.seek(0)
            scores_file.truncate()
            scores_file.write(str(sum_score))



from .GuessGame import GuessGame
from .MemoryGame import MemoryGame
from .CurrencyRouletteGame import CurrencyRouletteGame
from .MainScores import MainScores


def welcome(name):
    # Welcomes the user.
    return f"Hello {name} and welcome to the World of Games (WoG).\n" \
           f"Here you can find many cool games to play."


def load_game():
    # This func loads the option that the user chooses, and it start this option.
    option = input("Please choose one of the following options:\n"
                         "\t1. Memory Game - a sequence of numbers will "
                         "appear for 1 second and you have to guess it back\n"
                         "\t2. Guess Game - guess a number and see "
                         "if you chose like the computer\n"
                         "\t3. Currency Roulette - try and guess the value "
                         "of a random amount of USD in ILS\n"
                         "\t4. Showing result - Running on http://127.0.0.1:5000/ "
                         "accumulation of your winnings ")
    while not (option == "1" or option == "2" or option == "3" or option == "4"):
        option = input("Please choose the game to play, 1,2,3 or 4 ")
    dict_options = {"1": MemoryGame(), "2": GuessGame(), "3": CurrencyRouletteGame(), "4": MainScores()}
    option_chosen = dict_options[option]
    option_chosen.start_option()



from selenium import webdriver
from selenium.webdriver.common.keys import Keys
from selenium.common.exceptions import WebDriverException
import argparse

parser = argparse.ArgumentParser()
parser.add_argument('--url', action='store', help='Enter URL to test',
                    required=False, default='127.0.0.1:8777')
parser.add_argument('--driver', action='store', help='Enter selenium driver location',
                    required=False, default=r"C:\Users\tomer9000\chromedriver.exe")
arg = parser.parse_args()

def test_scores_service(app_url, driver_location):
    driver = webdriver.Chrome(fr"{driver_location}")
    try:
        driver.get(f"http://{app_url}/")
        q = driver.find_element_by_id("score")
        num_q = int(q.text)
        driver.close()
        print(num_q)
        return (num_q >= 1 or num_q <= 1000)
    except WebDriverException:
        driver.close()
        print(f"Website {app_url} isn't reachable")

def main_function(app_url, driver_location):
    if test_scores_service(app_url, driver_location):
        return 0
    return -1

print(main_function(arg.url, arg.driver))



from .Utils import Utils
from .Score import Score


class Game:
    """
    This class is the WOG's object which does
    necessary actions for each one of the games.
    """
    def __init__(self):
        """
        This runs every time a user calls the class
        and it initializes necessary variables.
        """
        self.game_difficulty = 0
        self.winning_status = False

    def set_difficulty(self):
        # This functioin asks for the game's difficulty.
        while (self.game_difficulty < 1) or (self.game_difficulty > 5):
            self.game_difficulty = input("Please choose game difficulty from 1 to 5: ")
            self.game_difficulty = Utils()._needs_number(self.game_difficulty)

    def win_or_lose(self):
        """
        This function prints whether the user won or lost the game.
        If the user won, it calls to a functions which adds it to the final score.
        """
        if self.winning_status:
            print("Well done, you are right!")
            Score(self.game_difficulty).add_score()
        else:
            print("Sorry, you didn't manage to win at this time.")

    def play(self):
        # This function is implemented in other classes.
        pass

    def start_option(self):
        # This function runs the game in the necessary order.
        self.set_difficulty()
        self.play()
        self.win_or_lose()



import os
from flask import Flask, render_template
from .Utils import Utils


class MainScores(Utils):
    """
    serve the user’s score currently in the scores.txt file over HTTP with HTML.
    """
    def __init__(self):
        """
        This runs every time a user calls the class
        and it initializes necessary variables.
        """
        Utils.__init__(self)
        self.app = Flask(__name__, template_folder=self.path_files)
        try:
            with open(os.path.join(self.path_files, self.scores_file_name), "r") as scores_file:
                scores_file.seek(0)
                self.score_from_file = scores_file.read()
            self.bad_return_code = 0
        except FileNotFoundError:
            self.bad_return_code = 1

    def start_option(self):
        """
        This function will serve the score. It will read the score
        from the scores file and will return an HTML.
        """
        if self.bad_return_code == 0:
            @self.app.route("/")
            def score_server():
                return render_template("scores_html.html", SCORE=self.score_from_file)
            self.app.run(port=8777)

        else:
            @self.app.route("/")
            def score_server():
                return render_template("error_html.html", ERROR="PROBLEM showing the result")
            self.app.run(port=8777)



import random
from .Utils import Utils
from .Game import Game


class GuessGame(Game):
    """
    This game generates a number which the user needs to guess,
    butween 1 to the difficult of the game.
    """
    def __init__(self):
        """
        This func runs automatically every time a user calls
        the class and it initializes the necessary variables.
        """
        Game.__init__(self)
        self.user_guess = 0

    def generate_number(self):
        # Generates a number that the user needs to guess.
        self.secret_number = random.randint(1, self.game_difficulty)

    def get_guess_from_user(self):
        # User guess the generated number.
        while self.user_guess < 1 or self.user_guess > self.game_difficulty:
            self.user_guess = input(f"Guess a number between 1 and {self.game_difficulty} ")
            self.user_guess = Utils()._needs_number(self.user_guess)

    def compare_results(self):
        """
        Check if the user guessed correcrly.
        :return: True/False depends if the user corrects.
        """
        return self.secret_number == self.user_guess

    def play(self):
        """
        When a user wants to play this game, he needs to call this func
        and it runs the relevant methods in the correct order.
        :return: True/False whether the user wins/loses.
        """
        self.generate_number()
        self.get_guess_from_user()
        print(f"The generated number is - {self.secret_number}")
        print(f"Your guess is - {self.user_guess}")
        self.winning_status = self.compare_results()



import os
import wog


class Utils:
    """
    A general purpose python file. This file will contain general information
    and operations we need for our game.
    """
    def __init__(self):
        self.scores_file_name = "Scores.txt"
        self.bad_return_code = 1
        self.path_files = os.path.dirname(wog.__file__)

    def screen_cleaner(self):
        # A function to clear the screen.
        os.system('cls' if os.name == 'nt' else 'clear')

    def _needs_number(self, user_input):
        """
        An inturnal use func, it forces the user to enter a number.
        :param user_input: The user input, which will be checked if it is a number.
        :return: returns an integer number.
        """
        while not user_input.isdigit():
            user_input = input("You need to enter a number ")
        return int(user_input)



import requests
import random
from inputimeout import inputimeout, TimeoutOccurred
from .Game import Game


class CurrencyRouletteGame(Game):
    """
    This class returns True if the user replies correctly on the value
    (generated between 1-100) from USD to ILS, else it returns False.
    """
    def __init__(self):
        """
        This func runs automatically every time a user calls
        the class and it initializes the necessary variables.
        """
        Game.__init__(self)
        exchage_rate_site = requests.get("https://api.exchangeratesapi.io"
                                         "/latest?base=USD&symbols=ILS")
        self.currency_exchange_rate = exchage_rate_site.json()["rates"]["ILS"]
        self.generated_number = random.randint(1, 100)
        self.final_value = self.generated_number * self.currency_exchange_rate
        self.final_value = round(self.final_value, 2)

    def get_money_interval(self):
        # Calculates the interval min and max value.
        self.min_value = self.final_value - (5 - self.game_difficulty)
        self.max_value = self.final_value + (5 - self.game_difficulty)

    def get_guess_from_user(self):
        """
        Gives the user a time to guess the answer
        and save the answer to a var self.user_input.
        """
        try:
            self.user_input = inputimeout(prompt=f"You have 5 seconds to answer, "
                                          f"what is the value of {self.generated_number} "
                                          f"in ILS? ", timeout=5)
        except TimeoutOccurred:
            self.user_input = "No"
        if self.user_input.isdigit() or self.user_input.replace(".", "", 1).isdigit():
            self.user_input = float(self.user_input)
        elif self.user_input == "No":
            pass
        else:
            self.user_input = 0

    def play(self):
        """
        When a user wants to play this game, he needs to call this func
        and it runs the relevant methods in the correct order.
        :return: True/False whether the user wins/loses.
        """
        self.get_money_interval()
        self.get_guess_from_user()
        if self.user_input == "No":
            print("It's been 5 seconds, sorry.")
            return False
        elif self.user_input == 0:
            print("You needed to enter a number")
            return False
        print(f"The correct value is {self.final_value}₪, "
              f"you needed to enter a number between {self.min_value} and {self.max_value}")
        self.winning_status = ((self.user_input > self.min_value) and (self.user_input < self.max_value))



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="wog-tomer9000",
    version="2.4",
    author="Tomer_Tzur",
    author_email="tomer9000@gmail.com",
    description="Package for DevOps course",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Tomer9000/WOG",
    packages=setuptools.find_packages(),
    install_requires=[
        'inputimeout',
        'requests',
        'flask',
        'selenium'
    ],
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.4',
)
